@@ -135,7 +135,8 @@ void DocSets::initialize()
     err("Could not open file %s for writing\n",notes.data());
     exit(1);
   }
-  QCString indexName=Config_getBool("GENERATE_TREEVIEW")?"main":"index";
+  //QCString indexName=Config_getBool("GENERATE_TREEVIEW")?"main":"index";
+  QCString indexName="index";
   m_nts.setDevice(m_nf);
   m_nts << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << endl;
   m_nts << "<DocSetNodes version=\"1.0\">" << endl;
@@ -210,7 +211,9 @@ void DocSets::addContentsItem(bool isDir,
                               const char *name, 
                               const char *ref, 
                               const char *file,
-                              const char *anchor)
+                              const char *anchor,
+                              bool /* separateIndex */,
+                              bool /* addToNavIndex */)
 {
   (void)isDir;
   if (file && ref==0)
@@ -253,7 +256,14 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,const char *)
   // determine language
   QCString lang;
   SrcLangExt langExt = SrcLangExt_Cpp;
-  if (fd) langExt = getLanguageFromFileName(fd->name());
+  if (md) 
+  {
+    langExt = md->getLanguage();
+  }
+  else if (context) 
+  {
+    langExt = context->getLanguage();
+  }
   switch (langExt)
   {
     case SrcLangExt_Cpp:
@@ -276,9 +286,10 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,const char *)
     case SrcLangExt_Java:    lang="java"; break;       // Java
     case SrcLangExt_JS:      lang="javascript"; break; // Javascript
     case SrcLangExt_Python:  lang="python"; break;     // Python
-    case SrcLangExt_F90:     lang="fortran"; break;    // Fortran
+    case SrcLangExt_Fortran: lang="fortran"; break;    // Fortran
     case SrcLangExt_VHDL:    lang="vhdl"; break;       // VHDL
     case SrcLangExt_XML:     lang="xml"; break;        // DBUS XML
+    case SrcLangExt_Tcl:     lang="tcl"; break;        // Tcl
     case SrcLangExt_Unknown: lang="unknown"; break;   // should not happen!
   }
 
