@@ -2,7 +2,8 @@
 "\n"
 "body, table, div, p, dl {\n"
 "	font-family: Lucida Grande, Verdana, Geneva, Arial, sans-serif;\n"
-"	font-size: 12px;\n"
+"	font-size: 13px;\n"
+"	line-height: 1.5;\n"
 "}\n"
 "\n"
 "/* @group Heading Levels */\n"
@@ -72,8 +73,6 @@
 "	background-color: ##ee;\n"
 "	border: 1px solid ##b0;\n"
 "	text-align: center;\n"
-"	margin: 2px;\n"
-"	padding: 2px;\n"
 "}\n"
 "\n"
 "div.qindex, div.navpath {\n"
@@ -124,11 +123,11 @@
 "}\n"
 "\n"
 "a.code {\n"
-"	color: ##60;\n"
+"	color: #4665A2; \n"
 "}\n"
 "\n"
 "a.codeRef {\n"
-"	color: ##60;\n"
+"	color: #4665A2; \n"
 "}\n"
 "\n"
 "/* @end */\n"
@@ -183,15 +182,15 @@
 "}\n"
 "\n"
 "body {\n"
-"	background: white;\n"
+"	background-color: white;\n"
 "	color: black;\n"
 "        margin: 0;\n"
 "}\n"
 "\n"
 "div.contents {\n"
 "	margin-top: 10px;\n"
-"	margin-left: 10px;\n"
-"	margin-right: 5px;\n"
+"	margin-left: 8px;\n"
+"	margin-right: 8px;\n"
 "}\n"
 "\n"
 "td.indexkey {\n"
@@ -200,6 +199,8 @@
 "	border: 1px solid ##cc;\n"
 "	margin: 2px 0px 2px 0;\n"
 "	padding: 2px 10px;\n"
+"        white-space: nowrap;\n"
+"        vertical-align: top;\n"
 "}\n"
 "\n"
 "td.indexvalue {\n"
@@ -414,7 +415,7 @@
 "        margin-left: 6px;\n"
 "}\n"
 "\n"
-".memproto {\n"
+".memproto, dl.reflist dt {\n"
 "        border-top: 1px solid ##B4;\n"
 "        border-left: 1px solid ##B4;\n"
 "        border-right: 1px solid ##B4;\n"
@@ -440,7 +441,7 @@
 "\n"
 "}\n"
 "\n"
-".memdoc {\n"
+".memdoc, dl.reflist dd {\n"
 "        border-bottom: 1px solid ##B4;      \n"
 "        border-left: 1px solid ##B4;      \n"
 "        border-right: 1px solid ##B4; \n"
@@ -463,6 +464,15 @@
 "        background-image: -webkit-gradient(linear,center top,center bottom,from(##FF), color-stop(0.6,##FF), color-stop(0.60,##FF), color-stop(0.95,##F8), to(##F0));\n"
 "}\n"
 "\n"
+"dl.reflist dt {\n"
+"        padding: 5px;\n"
+"}\n"
+"\n"
+"dl.reflist dd {\n"
+"        margin: 0px 0px 10px 0px;\n"
+"        padding: 5px;\n"
+"}\n"
+"\n"
 ".paramkey {\n"
 "	text-align: right;\n"
 "}\n"
@@ -622,6 +632,58 @@
 "	text-align:left;\n"
 "}\n"
 "\n"
+"table.fieldtable {\n"
+"        width: 100%;\n"
+"        margin-bottom: 10px;\n"
+"        border: 1px solid ##B4;\n"
+"        border-spacing: 0px;\n"
+"        -moz-border-radius: 4px;\n"
+"        -webkit-border-radius: 4px;\n"
+"        border-radius: 4px;\n"
+"        -moz-box-shadow: rgba(0, 0, 0, 0.15) 2px 2px 2px;\n"
+"        -webkit-box-shadow: 2px 2px 2px rgba(0, 0, 0, 0.15);\n"
+"        box-shadow: 2px 2px 2px rgba(0, 0, 0, 0.15);\n"
+"}\n"
+"\n"
+".fieldtable td, .fieldtable th {\n"
+"        padding: 3px 7px 2px;\n"
+"}\n"
+"\n"
+".fieldtable td.fieldtype, .fieldtable td.fieldname {\n"
+"        white-space: nowrap;\n"
+"        border-right: 1px solid ##B4;\n"
+"        border-bottom: 1px solid ##B4;\n"
+"        vertical-align: top;\n"
+"}\n"
+"\n"
+".fieldtable td.fielddoc {\n"
+"        border-bottom: 1px solid ##B4;\n"
+"        width: 100%;\n"
+"}\n"
+"\n"
+".fieldtable tr:last-child td {\n"
+"        border-bottom: none;\n"
+"}\n"
+"\n"
+".fieldtable th {\n"
+"        background-image:url('nav_f.png');\n"
+"        background-repeat:repeat-x;\n"
+"        background-color: ##E6;\n"
+"        font-size: 90%;\n"
+"        color: ##2B;\n"
+"        padding-bottom: 4px;\n"
+"        padding-top: 5px;\n"
+"        text-align:left;\n"
+"        -moz-border-radius-topleft: 4px;\n"
+"        -moz-border-radius-topright: 4px;\n"
+"        -webkit-border-top-left-radius: 4px;\n"
+"        -webkit-border-top-right-radius: 4px;\n"
+"        border-top-left-radius: 4px;\n"
+"        border-top-right-radius: 4px;\n"
+"        border-bottom: 1px solid ##B4;\n"
+"}\n"
+"\n"
+"\n"
 ".tabsearch {\n"
 "	top: 0px;\n"
 "	left: 10px;\n"
@@ -701,6 +763,7 @@
 "\n"
 "div.ingroups\n"
 "{\n"
+"	margin-left: 5px;\n"
 "	font-size: 8pt;\n"
 "	padding-left: 5px;\n"
 "	width: 50%;\n"
@@ -723,7 +786,7 @@
 "\n"
 "div.headertitle\n"
 "{\n"
-"	padding: 5px 5px 5px 10px;\n"
+"	padding: 5px 5px 5px 7px;\n"
 "}\n"
 "\n"
 "dl\n"
@@ -833,3 +896,54 @@
 "	font-weight: bold;\n"
 "}\n"
 "\n"
+"div.zoom\n"
+"{\n"
+"	border: 1px solid ##A0;\n"
+"}\n"
+"\n"
+"dl.citelist {\n"
+"        margin-bottom:50px;\n"
+"}\n"
+"\n"
+"dl.citelist dt {\n"
+"        color:##40;\n"
+"        float:left;\n"
+"        font-weight:bold;\n"
+"        margin-right:10px;\n"
+"        padding:5px;\n"
+"}\n"
+"\n"
+"dl.citelist dd {\n"
+"        margin:2px 0;\n"
+"        padding:5px 0;\n"
+"}\n"
+"\n"
+"@media print\n"
+"{\n"
+"  #top { display: none; }\n"
+"  #side-nav { display: none; }\n"
+"  #nav-path { display: none; }\n"
+"  body { overflow:visible; }\n"
+"  h1, h2, h3, h4, h5, h6 { page-break-after: avoid; }\n"
+"  .summary { display: none; }\n"
+"  .memitem { page-break-inside: avoid; }\n"
+"  #doc-content\n"
+"  {\n"
+"    margin-left:0 !important;\n"
+"    height:auto !important;\n"
+"    width:auto !important;\n"
+"    overflow:inherit;\n"
+"    display:inline;\n"
+"  }\n"
+"  pre.fragment\n"
+"  {\n"
+"    overflow: visible;\n"
+"    text-wrap: unrestricted;\n"
+"    white-space: -moz-pre-wrap; /* Moz */\n"
+"    white-space: -pre-wrap; /* Opera 4-6 */\n"
+"    white-space: -o-pre-wrap; /* Opera 7 */\n"
+"    white-space: pre-wrap; /* CSS3  */\n"
+"    word-wrap: break-word; /* IE 5.5+ */\n"
+"  }\n"
+"}\n"
+"\n"
