@@ -92,9 +92,10 @@ FileDef::FileDef(const char *p,const char *nm,
   {
     docname.prepend(stripFromPath(path.copy()));
   }
-  SrcLangExt lang   = getLanguageFromFileName(name());
-  m_isJava          = lang==SrcLangExt_Java;
-  m_isCSharp        = lang==SrcLangExt_CSharp;
+  SrcLangExt lang = getLanguageFromFileName(name());
+  setLanguage(lang);
+  //m_isJava          = lang==SrcLangExt_Java;
+  //m_isCSharp        = lang==SrcLangExt_CSharp;
   memberGroupSDict = 0;
   acquireFileVersion();
   m_subGrouping=Config_getBool("SUBGROUPING");
@@ -220,7 +221,7 @@ void FileDef::writeDetailedDescription(OutputList &ol,const QCString &title)
 
 void FileDef::writeBriefDescription(OutputList &ol)
 {
-  if (!briefDescription().isEmpty()) 
+  if (!briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
   {
     ol.startParagraph();
     ol.parseDoc(briefFile(),briefLine(),this,0,
@@ -260,71 +261,74 @@ void FileDef::writeIncludeFiles(OutputList &ol)
     IncludeInfo *ii;
     for (;(ii=ili.current());++ili)
     {
-      FileDef *fd=ii->fileDef;
-      bool isIDLorJava = FALSE;
-      if (fd)
+      if (!ii->indirect)
       {
-        SrcLangExt lang   = getLanguageFromFileName(fd->name());
-        isIDLorJava = lang==SrcLangExt_IDL || lang==SrcLangExt_Java;
-      }
-      ol.startTypewriter();
-      if (isIDLorJava) // IDL/Java include
-      {
-        ol.docify("import ");
-      }
-      else if (ii->imported) // Objective-C include
-      {
-        ol.docify("#import ");
-      }
-      else // C/C++ include
-      {
-        ol.docify("#include ");
-      }
-      if (ii->local || isIDLorJava)
-        ol.docify("\"");
-      else
-        ol.docify("<");
-      ol.disable(OutputGenerator::Html);
-      ol.docify(ii->includeName);
-      ol.enableAll();
-      ol.disableAllBut(OutputGenerator::Html);
-      
-      // Here we use the include file name as it appears in the file.
-      // we could also we the name as it is used within doxygen,
-      // then we should have used fd->docName() instead of ii->includeName
-      if (fd && fd->isLinkable())
-      {
-        ol.writeObjectLink(fd->getReference(),
-            fd->generateSourceFile() ? fd->includeName() : fd->getOutputFileBase(),
-            0,ii->includeName);
-        if (!Config_getString("GENERATE_TAGFILE").isEmpty() && !fd->isReference()) 
+        FileDef *fd=ii->fileDef;
+        bool isIDLorJava = FALSE;
+        if (fd)
         {
-          const char *locStr = (ii->local    || isIDLorJava) ? "yes" : "no";
-          const char *impStr = (ii->imported || isIDLorJava) ? "yes" : "no";
-          Doxygen::tagFile << "    <includes id=\"" 
-                           << convertToXML(fd->getOutputFileBase()) << "\" "
-                           << "name=\"" << convertToXML(fd->name()) << "\" "
-                           << "local=\"" << locStr << "\" "
-                           << "imported=\"" << impStr << "\">"
-                           << convertToXML(ii->includeName)
-                           << "</includes>" 
-                           << endl;
+          SrcLangExt lang   = fd->getLanguage();
+          isIDLorJava = lang==SrcLangExt_IDL || lang==SrcLangExt_Java;
         }
-      }
-      else
-      {
+        ol.startTypewriter();
+        if (isIDLorJava) // IDL/Java include
+        {
+          ol.docify("import ");
+        }
+        else if (ii->imported) // Objective-C include
+        {
+          ol.docify("#import ");
+        }
+        else // C/C++ include
+        {
+          ol.docify("#include ");
+        }
+        if (ii->local || isIDLorJava)
+          ol.docify("\"");
+        else
+          ol.docify("<");
+        ol.disable(OutputGenerator::Html);
         ol.docify(ii->includeName);
+        ol.enableAll();
+        ol.disableAllBut(OutputGenerator::Html);
+        
+        // Here we use the include file name as it appears in the file.
+        // we could also we the name as it is used within doxygen,
+        // then we should have used fd->docName() instead of ii->includeName
+        if (fd && fd->isLinkable())
+        {
+          ol.writeObjectLink(fd->getReference(),
+              fd->generateSourceFile() ? fd->includeName() : fd->getOutputFileBase(),
+              0,ii->includeName);
+          if (!Config_getString("GENERATE_TAGFILE").isEmpty() && !fd->isReference()) 
+          {
+            const char *locStr = (ii->local    || isIDLorJava) ? "yes" : "no";
+            const char *impStr = (ii->imported || isIDLorJava) ? "yes" : "no";
+            Doxygen::tagFile << "    <includes id=\"" 
+                             << convertToXML(fd->getOutputFileBase()) << "\" "
+                             << "name=\"" << convertToXML(fd->name()) << "\" "
+                             << "local=\"" << locStr << "\" "
+                             << "imported=\"" << impStr << "\">"
+                             << convertToXML(ii->includeName)
+                             << "</includes>" 
+                             << endl;
+          }
+        }
+        else
+        {
+          ol.docify(ii->includeName);
+        }
+        
+        ol.enableAll();
+        if (ii->local || isIDLorJava)
+          ol.docify("\"");
+        else
+          ol.docify(">");
+        if (isIDLorJava) 
+          ol.docify(";");
+        ol.endTypewriter();
+        ol.lineBreak();
       }
-      
-      ol.enableAll();
-      if (ii->local || isIDLorJava)
-        ol.docify("\"");
-      else
-        ol.docify(">");
-      if (isIDLorJava) 
-        ol.docify(";");
-      ol.endTypewriter();
-      ol.lineBreak();
     }
     ol.endTextBlock();
   }
@@ -398,6 +402,11 @@ void FileDef::writeClassDeclarations(OutputList &ol,const QCString &title)
   if (classSDict) classSDict->writeDeclaration(ol,0,title,FALSE);
 }
 
+void FileDef::writeInlineClasses(OutputList &ol)
+{
+  if (classSDict) classSDict->writeDocumentation(ol,this);
+}
+
 void FileDef::startMemberDeclarations(OutputList &ol)
 {
   ol.startMemberSections();
@@ -636,6 +645,9 @@ void FileDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::MemberDefStart: 
         startMemberDocumentation(ol);
         break; 
+      case LayoutDocEntry::FileInlineClasses:
+        writeInlineClasses(ol);
+        break;
       case LayoutDocEntry::MemberDef: 
         {
           LayoutDocEntryMemberDef *lmd = (LayoutDocEntryMemberDef*)lde;
@@ -654,8 +666,10 @@ void FileDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::ClassCollaborationGraph:
       case LayoutDocEntry::ClassAllMembersLink:
       case LayoutDocEntry::ClassUsedFiles:
+      case LayoutDocEntry::ClassInlineClasses:
       case LayoutDocEntry::NamespaceNestedNamespaces:
       case LayoutDocEntry::NamespaceClasses:
+      case LayoutDocEntry::NamespaceInlineClasses:
       case LayoutDocEntry::GroupClasses: 
       case LayoutDocEntry::GroupInlineClasses: 
       case LayoutDocEntry::GroupNamespaces:
@@ -683,12 +697,7 @@ void FileDef::writeDocumentation(OutputList &ol)
 
   ol.endContents();
 
-  if (generateTreeView)
-  {
-    writeNavigationPath(ol);
-  }
-
-  endFile(ol,TRUE);
+  endFileWithNavPath(this,ol);
 
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
@@ -747,7 +756,7 @@ void FileDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
           if (createSubDirs) ol.writeString("../../");
           ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
           ol.writeString("\">");
-          ol.writeString(md->localName());
+          ol.writeString(convertToHtml(md->localName()));
           ol.writeString("</a>");
         }
         ol.writeString("</td></tr>\n");
@@ -817,15 +826,7 @@ void FileDef::writeSource(OutputList &ol)
            );
   ol.endCodeFragment();
   ol.endContents();
-  if (generateTreeView)
-  {
-    writeNavigationPath(ol);
-    endFile(ol,TRUE);
-  }
-  else
-  {
-    endFile(ol);
-  }
+  endFileWithNavPath(this,ol);
   ol.enableAll();
 }
 
@@ -1023,7 +1024,7 @@ void FileDef::addUsingDeclaration(Definition *d)
 }
 
 void FileDef::addIncludeDependency(FileDef *fd,const char *incName,bool local,
-                                   bool imported)
+                                   bool imported,bool indirect)
 {
   //printf("FileDef::addIncludeDependency(%p,%s,%d)\n",fd,incName,local);
   QCString iName = fd ? fd->absFilePath().data() : incName;
@@ -1040,6 +1041,7 @@ void FileDef::addIncludeDependency(FileDef *fd,const char *incName,bool local,
     ii->includeName = incName;
     ii->local       = local;
     ii->imported    = imported;
+    ii->indirect    = indirect;
     includeList->append(ii);
     includeDict->insert(iName,ii);
   }
@@ -1137,6 +1139,7 @@ void FileDef::addIncludedByDependency(FileDef *fd,const char *incName,
     ii->includeName = incName;
     ii->local       = local;
     ii->imported    = imported;
+    ii->indirect    = FALSE;
     includedByList->append(ii);
     includedByDict->insert(iName,ii);
   }
@@ -1487,7 +1490,7 @@ bool FileDef::isDocumentationFile() const
 void FileDef::acquireFileVersion()
 {
   QCString vercmd = Config_getString("FILE_VERSION_FILTER");
-  if (!vercmd.isEmpty() && filepath!="generated") 
+  if (!vercmd.isEmpty() && !filepath.isEmpty() && filepath!="generated") 
   {
     msg("Version of %s : ",filepath.data());
     QCString cmd = vercmd+" \""+filepath+"\"";
@@ -1502,9 +1505,8 @@ void FileDef::acquireFileVersion()
     char buf[bufSize];
     int numRead = fread(buf,1,bufSize,f);
     portable_pclose(f);
-    if (numRead > 0) 
+    if (numRead>0 && !(fileVersion=QCString(buf,numRead).stripWhiteSpace()).isEmpty())
     {
-      fileVersion = QCString(buf,numRead).stripWhiteSpace();
       msg("%s\n",fileVersion.data());
     }
     else 
@@ -1613,7 +1615,8 @@ void FileDef::writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,con
   {
     if (optVhdl) // use specific declarations function
     {
-      VhdlDocGen::writeVhdlDeclarations(ml,ol,0,0,this);
+
+      VhdlDocGen::writeVhdlDeclarations(ml,ol,0,0,this,0);
     }
     else
     {
@@ -1634,10 +1637,11 @@ bool FileDef::isLinkableInProject() const
   return hasDocumentation() && !isReference() && showFiles;
 }
 
+#if 0
 bool FileDef::includes(FileDef *incFile,QDict<FileDef> *includedFiles) const
 {
-  if (incFile==this) return TRUE;
   //printf("%s::includes(%s)\n",name().data(),incFile->name().data());
+  if (incFile==this) return TRUE;
   includedFiles->insert(absFilePath(),this);
   if (includeList)
   {
@@ -1645,12 +1649,30 @@ bool FileDef::includes(FileDef *incFile,QDict<FileDef> *includedFiles) const
     IncludeInfo *ii;
     for (;(ii=ili.current());++ili)
     {
-      if (ii->fileDef && 
-          includedFiles->find(ii->fileDef->absFilePath())==0 &&
-          ii->fileDef->includes(incFile,includedFiles)) return TRUE;
+      //printf("ii=%s\n",ii->includeName.data());
+      if ((ii->fileDef && 
+           includedFiles->find(ii->fileDef->absFilePath())==0 &&
+           ii->fileDef->includes(incFile,includedFiles)
+          ) ||
+          incFile->absFilePath()==ii->includeName
+         ) return TRUE;
     }
   }
   return FALSE;
 }
 
-
+bool FileDef::includesByName(const QCString &fileName) const
+{
+  if (includeList)
+  {
+    QListIterator<IncludeInfo> ili(*includeList);
+    IncludeInfo *ii;
+    for (;(ii=ili.current());++ili)
+    {
+      //printf("ii=%s\n",ii->includeName.data());
+      if (fileName==ii->includeName) return TRUE;
+    }
+  }
+  return FALSE;
+}
+#endif
