@@ -30,6 +30,7 @@
 #include <string.h>
 #include "docparser.h"
 #include "mandocvisitor.h"
+#include "language.h"
 
 static QCString getExtension()
 {
@@ -278,6 +279,7 @@ void ManGenerator::docify(const char *str)
     {
       switch(c)
       {
+        case '.':  t << "\\&."; break; // see  bug652277
         case '\\': t << "\\\\"; col++; break;
         case '\n': t << "\n"; col=0; break;
         case '\"':  c = '\''; // no break!
@@ -303,6 +305,7 @@ void ManGenerator::codify(const char *str)
       c=*p++;
       switch(c)
       {
+        case '.':   t << "\\&."; break; // see  bug652277
         case '\t':  spacesToNextTabStop =
                           Config_getInt("TAB_SIZE") - (col%Config_getInt("TAB_SIZE"));
                     t << Doxygen::spaces.left(spacesToNextTabStop); 
@@ -715,13 +718,6 @@ void ManGenerator::endConstraintList()
 {
 }
 
-void ManGenerator::startInlineDescription() 
-{
-}
-
-void ManGenerator::endInlineDescription() 
-{
-}
 
 void ManGenerator::startInlineHeader() 
 {
@@ -738,5 +734,54 @@ void ManGenerator::endInlineHeader()
   firstCol = FALSE;
 }
 
+void ManGenerator::startMemberDocSimple()
+{
+  if (!firstCol) 
+  {
+    t << endl << ".PP" << endl;
+  }
+  t << "\\fB";
+  docify(theTranslator->trCompoundMembers());
+  t << ":\\fP" << endl;
+  t << ".RS 4" << endl;
+}
 
+void ManGenerator::endMemberDocSimple()
+{
+  if (!firstCol) t << endl;
+  t << ".RE" << endl;
+  t << ".PP" << endl;
+  firstCol=TRUE;
+}
+
+void ManGenerator::startInlineMemberType()
+{
+}
+
+void ManGenerator::endInlineMemberType()
+{
+  t << " ";
+}
+
+void ManGenerator::startInlineMemberName()
+{
+  t << "\\fI";
+}
+
+void ManGenerator::endInlineMemberName()
+{
+  t << "\\fP ";
+}
+
+void ManGenerator::startInlineMemberDoc()
+{
+}
+
+void ManGenerator::endInlineMemberDoc()
+{
+  if (!firstCol) t << endl;
+  t << ".br" << endl;
+  t << ".PP" << endl;
+  firstCol=TRUE;
+}
 
