@@ -2,7 +2,7 @@
  *
  * $Id: scanner.h,v 1.15 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -43,7 +43,8 @@ class CLanguageScanner : public ParserInterface
                    int startLine=-1,
                    int endLine=-1,
                    bool inlineFragment=FALSE,
-                   MemberDef *memberDef=0
+                   MemberDef *memberDef=0,
+                   bool showLineNumbers=TRUE
                   );
     void resetCodeParserState();
     void parsePrototype(const char *text);
