@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -87,7 +87,6 @@
 #ifndef TRANSLATOR_DK_H
 #define TRANSLATOR_DK_H
 
-// class TranslatorDanish : public TranslatorAdapter_1_5_4
 class TranslatorDanish : public Translator
 {
   public:
@@ -1797,6 +1796,25 @@ class TranslatorDanish : public Translator
       return sdate;
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.7.5
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trCiteReferences()
+    {
+      return "Bibliografiske referencer"; 
+    }
+
+    virtual QCString trCopyright()
+    {
+      return "Copyright";
+    }
+
+    virtual QCString trDirDepGraph(const char *name)
+    {
+      return QCString("Afhngighedsgraf for katalog ")+name+":"; 
+    }
+
 
 /*---------- For internal use: ----------------------------------------*/
   protected:
