@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -738,6 +738,16 @@ class TranslatorDecoder : public Translator
                                              hour,minutes,seconds,includeTime)); 
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.7.5
+//////////////////////////////////////////////////////////////////////////
+
+    QCString trCiteReferences()
+    { return toUtf8(m_translator->trCiteReferences()); }
+    QCString trCopyright()
+    { return toUtf8(m_translator->trCopyright()); }
+    QCString trDirDepGraph(const char *name)
+    { return toUtf8(m_translator->trDirDepGraph(fromUtf8(name))); }
 
 //////////////////////////////////////////////////////////////////////////
   private:
